import React, { useCallback } from 'react';
import { connect, history } from 'umi';
import { Space } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import School from '@/components/School';
import { queryTable } from '@/utils/request';
import Specialty from '@/components/Specialty';

const StudentList = () => {
  const handleStudentClick = useCallback((id) => {
    if (id) {
      history.push(`/student/student/edit?id=${id}`);
    }
  }, []);

  const columns = [
    {
      title: '编号',
      dataIndex: 'personId',
      align: 'center',
      width: 300,
      hideInSearch: true,
    },
    {
      title: '姓名',
      dataIndex: 'name',
      align: 'center',
    },
    {
      title: '微信昵称',
      dataIndex: 'nickName',
      align: 'center',
      hideInSearch: true,
    },
    {
      title: '联系方式',
      dataIndex: 'phone',

      align: 'center',
    },
    {
      title: '学校',
      dataIndex: 'schoolId',
      align: 'center',
      render: (_, row) => row.schoolName,
      renderFormItem: () => <School autoDefault={false} allowClear></School>,
    },
    {
      title: '专业',
      dataIndex: 'specialtyId',
      align: 'center',
      render: (_, row) => row.specialtyName,
      renderFormItem: (item, config, form) => {
        const schoolId = form.getFieldValue('schoolId');
        return <Specialty schoolid={schoolId} disabled={!schoolId}></Specialty>;
      },
    },
    {
      title: '学号',
      dataIndex: 'studentId',
      align: 'center',
    },
    {
      title: '操作',
      dataIndex: 'action',
      align: 'center',
      hideInSearch: true,
      render: (text, record) => (
        <Space size="middle">
          <a onClick={() => handleStudentClick(record.personId)}>用户详情 </a>
        </Space>
      ),
    },
  ];

  return (
    <PageContainer>
      <ProTable
        columns={columns}
        request={queryTable('/person')}
        rowKey="personId"
        headerTitle="学校列表"
        search={{
          labelWidth: '4em',
        }}
      />
    </PageContainer>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(StudentList);
