import React, { useEffect, useState } from 'react'
import { connect } from 'umi'
import { Button, Checkbox, Row, Col, Divider, notification } from 'antd'
import request from '@/utils/request';

const UserRole = (props) => {
  const [loading, setLoading] = useState(false);
  const [checkedList, setCheckedList] = useState([])
  const [indeterminate, setIndeterminate] = useState(true);
  const [checkAll, setCheckAll] = useState(false);
  const [allRoles, setAllRoles] = useState([])

  const handleChange = (list) => {
    setCheckedList(list);
    setIndeterminate(!!list.length && list.length < allRoles.length);
    setCheckAll(list.length === allRoles.length);
  }

  const handleCheckAll = (e) => {
    setCheckedList(e.target.checked ? allRoles : []);
    setIndeterminate(false);
    setCheckAll(e.target.checked);
  }

  const handleSubmit = () => {
    if (props.user.userId) {
      const data = checkedList.map((roleId) => ({ userId: props.user.userId, roleId }))
      setLoading(true)
      request(`/user-role/${props.user.userId}`, { method: 'post',  data })
        .then((res) => {
          props.onSubmit(res);
          setLoading(false);
          notification.success({ message: '操作成功' });
        })
        .catch((e) => {
          setLoading(false);
          notification.error({ message: e.message });
        });
    } else {
      notification.error({ message: '请先保存用户信息' });
    }
  }

  useEffect(() => {
    if (!props.roleList?.length) {
      props.dispatch({
        type: 'user/fetchRoles',
      })
    } else {
      setAllRoles(props.roleList.map((r) => r.roleId))
    }

    if (props.user.roleList) {
      setCheckedList(props.user.roleList?.map((r) => r.roleId))
    }

    setIndeterminate(props.user.roleList?.length < props.roleList?.length);
    setCheckAll(props.user.roleList?.length === props.roleList?.length);
  }, [props])

  return (
    <div>
      <Checkbox indeterminate={indeterminate} onChange={handleCheckAll} checked={checkAll}>
        全选
      </Checkbox>
      <Divider />
      <Checkbox.Group value={checkedList} onChange={handleChange} style={{ width: '100%' }}>
        <Row>
          {
            (props.roleList || []).map((role) => {
              return (
                <Col span={8} key={role.roleId}>
                  <Checkbox value={role.roleId}>{role.name}</Checkbox>
                </Col>
              )
            })
          }
        </Row>
      </Checkbox.Group>
      <div style={{ marginTop: '3em' }}>
        <Button type="primary" onClick={handleSubmit} loading={loading}>确定</Button>
      </div>
    </div>
  )
}

export default connect((s) => ({
  roleList: s.user.roles,
}))(UserRole)
